# Changelog

<!--next-version-placeholder-->

## v0.1.1 (2025-05-09)

### Fix

* Better `list` support ([`85bd949`](https://github.com/educationwarehouse/sleazy/commit/85bd94982ef60241b70704e4af4c82184290adce))

## v0.1.0 (2025-05-09)

### Feature

* Initial version ([`45c278b`](https://github.com/educationwarehouse/sleazy/commit/45c278be0ed53566f40ea26e38ce796bb6ca6f13))
